#undef PACKAGE
#undef VERSION
#undef HAVE_LIBSM
#undef HAVE_CATGETS
#undef HAVE_GETTEXT
#undef HAVE_LC_MESSAGES
#undef HAVE_STPCPY
#undef ENABLE_NLS
#undef USE_PTHREAD
#undef HAVE_SOCKET
#undef HAVE_STRUCT_LINGER
#undef HAVE_NSL
#undef GNOME_VFS_DEFAULT_BACKEND
#undef USING_OAF
#undef HAVE_GCONF
